package org.ids_mannheim;

import java.io.File;
import java.io.IOException;
import java.nio.file.AccessDeniedException;
import java.nio.file.FileAlreadyExistsException;
import java.nio.file.Files;

public class Utils {
    public static String newExtension(String original, String newExtension) {
        if(original.equals("-"))
            throw new IllegalArgumentException("Cannot add a file name extension to stdout.");
        if (original.contains("."))
            return original.replaceFirst("(\\.[^.]*|\\.[^.]+\\.gz)$", "."+newExtension);
        else
            return original+".log";
    }

    public static File createFile(String fname, boolean force_overwrite) {
        File f = new File(fname);
        try {
            Files.createFile(f.toPath());
        } catch (AccessDeniedException e) {
            final String message = "ERROR: Cannot write file '" + fname + "'";
            System.err.println(message);
            TotalNGrams.logger.severe(message);
            System.exit(-1);
        } catch (FileAlreadyExistsException e) {
            if (!force_overwrite) {
                final String message = "ERROR: '" + fname + "' already exits. Use --force to overwrite";
                TotalNGrams.logger.severe(message);
                System.err.println(message);
                System.exit(-1);
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
        return f;
    }

    @org.jetbrains.annotations.NotNull
    public static String unEscapeEntities(String s) {
        return s.replace("&amp;", "&")
                .replace("&apos;", "'")
                .replace("&quot;", "\"")
                .replace("&lt;", "<")
                .replace("&gt;", ">");
    }

    public static String fixEscapedConlluEntities(String s) {
        return s.replaceAll("^(\\d+)\t&apos;\t--\t[^\t]+", "$1\t'\t\"\t\\$(")
                .replaceAll("^(\\d+)\t&quot;\t--\t[^\t]+", "$1\t\"\t\"\t\\$(")
                .replaceAll("^(\\d+)\t&amp;\t--\t[^\t]+", "$1\t&\t&amp;\tKON")
                .replaceAll("^(\\d+)\t&lt;\t--\t[^\t]+", "$1\t<\t&lt;\t\\$(")
                .replaceAll("^(\\d+)\t&gt;\t--\t[^\t]+", "$1\t>\t&gt;\t\\$(");
    }

    public static boolean isPunctuation(String token, String lemma, String pos) {
        return pos.startsWith("$") || token.equals("\"") || token.equals("'") || token.equals("<") || token.equals(">");
    }
}

